@@ -15,8 +15,7 @@ def test_auto_mapper_columns(spark_session: SparkSession) -> None:
         [
             (1, 'Qureshi', 'Imran'),
             (2, 'Vidal', 'Michael'),
-        ],
-        ['member_id', 'last_name', 'first_name']
+        ], ['member_id', 'last_name', 'first_name']
     ).createOrReplaceTempView("patients")
 
     source_df: DataFrame = spark_session.table("patients")
@@ -26,42 +25,36 @@ def test_auto_mapper_columns(spark_session: SparkSession) -> None:
 
     # Act
     mapper = AutoMapper(
-        view="members",
-        source_view="patients",
-        keys=["member_id"]
+        view="members", source_view="patients", keys=["member_id"]
     ).columns(
         dst1="src1",
-        dst2=A.list(
-            "address1"
-        ),
-        dst3=A.list(
-            ["address1", "address2"]
-        ),
-        dst4=A.list(
-            A.complex(
-                use="usual",
-                family=A.column("last_name")
-            )
-        )
+        dst2=A.list("address1"),
+        dst3=A.list(["address1", "address2"]),
+        dst4=A.list(A.complex(use="usual", family=A.column("last_name")))
     )
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(
+        source_df=source_df
+    )
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
     # Assert
     assert len(sql_expressions) == 4
     assert str(sql_expressions["dst1"]) == str(lit("src1").alias("dst1"))
-    assert str(sql_expressions["dst2"]) == str(array(lit("address1")).alias("dst2"))
-    assert str(sql_expressions["dst3"]) == str(array(lit("address1"), lit("address2")).alias("dst3"))
+    assert str(sql_expressions["dst2"]
+               ) == str(array(lit("address1")).alias("dst2"))
+    assert str(sql_expressions["dst3"]
+               ) == str(array(lit("address1"), lit("address2")).alias("dst3"))
     assert str(sql_expressions["dst4"]) == str(
         array(
             struct(
                 lit("usual").alias("use"),
                 col("last_name").alias("family")
             )
-        ).alias("dst4"))
+        ).alias("dst4")
+    )
 
     result_df: DataFrame = mapper.transform(df=df)
 
@@ -70,11 +63,17 @@ def test_auto_mapper_columns(spark_session: SparkSession) -> None:
     result_df.show()
 
     assert len(result_df.columns) == 5
-    assert result_df.where("member_id == 1").select("dst1").collect()[0][0] == "src1"
-    assert result_df.where("member_id == 1").select("dst2").collect()[0][0][0] == "address1"
+    assert result_df.where("member_id == 1").select("dst1"
+                                                    ).collect()[0][0] == "src1"
+    assert result_df.where("member_id == 1"
+                           ).select("dst2").collect()[0][0][0] == "address1"
 
-    assert result_df.where("member_id == 1").select("dst3").collect()[0][0][0] == "address1"
-    assert result_df.where("member_id == 1").select("dst3").collect()[0][0][1] == "address2"
+    assert result_df.where("member_id == 1"
+                           ).select("dst3").collect()[0][0][0] == "address1"
+    assert result_df.where("member_id == 1"
+                           ).select("dst3").collect()[0][0][1] == "address2"
 
-    assert result_df.where("member_id == 1").select("dst4").collect()[0][0][0][0] == "usual"
-    assert result_df.where("member_id == 1").select("dst4").collect()[0][0][0][1] == "Qureshi"
+    assert result_df.where("member_id == 1"
+                           ).select("dst4").collect()[0][0][0][0] == "usual"
+    assert result_df.where("member_id == 1"
+                           ).select("dst4").collect()[0][0][0][1] == "Qureshi"
