@@ -15,8 +15,7 @@ def test_auto_mapper_array_multiple_items(spark_session: SparkSession) -> None:
         [
             (1, 'Qureshi', 'Imran'),
             (2, 'Vidal', 'Michael'),
-        ],
-        ['member_id', 'last_name', 'first_name']
+        ], ['member_id', 'last_name', 'first_name']
     ).createOrReplaceTempView("patients")
 
     source_df: DataFrame = spark_session.table("patients")
@@ -26,24 +25,18 @@ def test_auto_mapper_array_multiple_items(spark_session: SparkSession) -> None:
 
     # Act
     mapper = AutoMapper(
-        view="members",
-        source_view="patients",
-        keys=["member_id"]
-    ).columns(
-        dst2=A.list(
-            [
-                "address1",
-                "address2"
-            ]
-        )
-    )
+        view="members", source_view="patients", keys=["member_id"]
+    ).columns(dst2=A.list(["address1", "address2"]))
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(
+        source_df=source_df
+    )
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["dst2"]) == str(array(lit("address1"), lit("address2")).alias("dst2"))
+    assert str(sql_expressions["dst2"]
+               ) == str(array(lit("address1"), lit("address2")).alias("dst2"))
 
     result_df: DataFrame = mapper.transform(df=df)
 
@@ -51,7 +44,11 @@ def test_auto_mapper_array_multiple_items(spark_session: SparkSession) -> None:
     result_df.printSchema()
     result_df.show()
 
-    assert result_df.where("member_id == 1").select("dst2").collect()[0][0][0] == "address1"
-    assert result_df.where("member_id == 1").select("dst2").collect()[0][0][1] == "address2"
-    assert result_df.where("member_id == 2").select("dst2").collect()[0][0][0] == "address1"
-    assert result_df.where("member_id == 2").select("dst2").collect()[0][0][1] == "address2"
+    assert result_df.where("member_id == 1"
+                           ).select("dst2").collect()[0][0][0] == "address1"
+    assert result_df.where("member_id == 1"
+                           ).select("dst2").collect()[0][0][1] == "address2"
+    assert result_df.where("member_id == 2"
+                           ).select("dst2").collect()[0][0][0] == "address1"
+    assert result_df.where("member_id == 2"
+                           ).select("dst2").collect()[0][0][1] == "address2"
