@@ -14,8 +14,7 @@ def test_auto_mapper_with_column(spark_session: SparkSession) -> None:
         [
             (1, 'Qureshi', 'Imran'),
             (2, 'Vidal', 'Michael'),
-        ],
-        ['member_id', 'last_name', 'first_name']
+        ], ['member_id', 'last_name', 'first_name']
     ).createOrReplaceTempView("patients")
 
     source_df: DataFrame = spark_session.table("patients")
@@ -25,19 +24,18 @@ def test_auto_mapper_with_column(spark_session: SparkSession) -> None:
 
     # Act
     mapper = AutoMapper(
-        view="members",
-        source_view="patients",
-        keys=["member_id"]
-    ).columns(
-        lname=A.column("last_name")
-    )
+        view="members", source_view="patients", keys=["member_id"]
+    ).columns(lname=A.column("last_name"))
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(
+        source_df=source_df
+    )
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["lname"]) == str(expr("last_name").alias("lname"))
+    assert str(sql_expressions["lname"]
+               ) == str(expr("last_name").alias("lname"))
 
     result_df: DataFrame = mapper.transform(df=df)
 
@@ -45,5 +43,7 @@ def test_auto_mapper_with_column(spark_session: SparkSession) -> None:
     result_df.printSchema()
     result_df.show()
 
-    assert result_df.where("member_id == 1").select("lname").collect()[0][0] == "Qureshi"
-    assert result_df.where("member_id == 2").select("lname").collect()[0][0] == "Vidal"
+    assert result_df.where("member_id == 1"
+                           ).select("lname").collect()[0][0] == "Qureshi"
+    assert result_df.where("member_id == 2"
+                           ).select("lname").collect()[0][0] == "Vidal"
