@@ -13,8 +13,7 @@ def test_auto_mapper_with_column_literal(spark_session: SparkSession) -> None:
         [
             (1, 'Qureshi', 'Imran'),
             (2, 'Vidal', 'Michael'),
-        ],
-        ['member_id', 'last_name', 'first_name']
+        ], ['member_id', 'last_name', 'first_name']
     ).createOrReplaceTempView("patients")
 
     source_df: DataFrame = spark_session.table("patients")
@@ -24,19 +23,18 @@ def test_auto_mapper_with_column_literal(spark_session: SparkSession) -> None:
 
     # Act
     mapper = AutoMapper(
-        view="members",
-        source_view="patients",
-        keys=["member_id"]
-    ).columns(
-        lname="last_name"
-    )
+        view="members", source_view="patients", keys=["member_id"]
+    ).columns(lname="last_name")
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(
+        source_df=source_df
+    )
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["lname"]) == str(lit("last_name").alias("lname"))
+    assert str(sql_expressions["lname"]
+               ) == str(lit("last_name").alias("lname"))
 
     result_df: DataFrame = mapper.transform(df=df)
 
@@ -44,5 +42,7 @@ def test_auto_mapper_with_column_literal(spark_session: SparkSession) -> None:
     result_df.printSchema()
     result_df.show()
 
-    assert result_df.where("member_id == 1").select("lname").collect()[0][0] == "last_name"
-    assert result_df.where("member_id == 2").select("lname").collect()[0][0] == "last_name"
+    assert result_df.where("member_id == 1"
+                           ).select("lname").collect()[0][0] == "last_name"
+    assert result_df.where("member_id == 2"
+                           ).select("lname").collect()[0][0] == "last_name"
